IANA Language Tags for Python
_____________________________

.. image:: https://badge.fury.io/py/language_tags.png
        :target: http://badge.fury.io/py/language_tags
.. image:: https://travis-ci.org/OnroerendErfgoed/language-tags.png?branch=master
        :target: https://travis-ci.org/OnroerendErfgoed/language-tags
.. image:: https://coveralls.io/repos/OnroerendErfgoed/language-tags/badge.png
        :target: https://coveralls.io/r/OnroerendErfgoed/language-tags
.. image:: https://readthedocs.org/projects/language-tags/badge/?version=latest
        :target: https://readthedocs.org/projects/language-tags/?badge=latest

This Python API offers a way to validate and lookup languages tags.

Standard
________

It is based on `BCP 47 <http://tools.ietf.org/html/bcp47>`_ (`RFC 5646 <http://tools.ietf.org/html/rfc5646>`_) and the latest `IANA language subtag registry <http://www.iana.org/assignments/language-subtag-registry>`_.

This project will be updated as the standards change.

JSON data
_________

See the `language-subtag-registry <https://github.com/mattcg/language-subtag-registry>`_ project for the underlying JSON data.

Javascript version
__________________

This project is a Python version of the `language-tags <https://github.com/mattcg/language-tags>`_ Javascript project.